@@ -70,7 +70,7 @@ define ([
             'menuText': 'Priv (status) menu',
             'title': 'Priv (status)',
             'aclProfile': 'passerby',
-            'entries': ['privHistory'],
+            'entries': ['actionPrivHistory'],
             'back': 'mainMenu'
         });
 
