@@ -57,19 +57,6 @@ define ([
             'back': 'demoMenu'
         });
 
-        // privHistory listing
-        target.push('privHistory', {
-            'name': 'privHistory',
-            'type': 'dnotice',
-            'menuText': 'Priv (status) history',
-            'title': 'Priv (status) history',
-            'preamble': '<span style="text-decoration: underline">Effective date/time</span>' +
-                        '&nbsp;&nbsp;&nbsp;' +
-                        '<span style="text-decoration: underline">Priv level&nbsp;&nbsp;</span>',
-            'aclProfile': 'passerby',
-            'back': 'mainPriv'
-        });
-
     };
 
 });
